@@ -10,11 +10,11 @@ from dateutil.tz import tzutc
 from powerbot_client import Configuration, ApiClient, ContractApi, Signal, Trade, \
 	InternalTrade, OwnOrder
 
+from powerbot_backtesting.historic_data_acquisition import get_historic_contract_ids
+from powerbot_backtesting.models import HistoryApiClient
 from powerbot_backtesting.utils import _cache_data, _check_contracts, _get_file_cachepath, _find_cache, \
 	_get_private_data
-from powerbot_backtesting.historic_data_acquisition import get_historic_contract_ids
 from powerbot_backtesting.utils.constants import *
-from powerbot_backtesting.models import HistoryApiClient
 
 
 def init_client(api_key: str, host: str) -> ApiClient:
@@ -115,8 +115,10 @@ def get_contract_ids(api_client: Union[ApiClient, HistoryApiClient],
 				new_contracts = contract_api.find_contracts(delivery_start=time_from)
 
 			# Check validity and add to contracts
-			[contracts[f"{time_from.strftime(DATE_YMD_TIME_HM)} - {c.delivery_end.strftime(TIME_HM)}"].append(c) for c
-			 in new_contracts if _check_contracts(c, delivery_areas, products, allow_udc)]
+			[contracts[f"{time_from.strftime(DATE_YMD_TIME_HM)} - {c.delivery_end.strftime(TIME_HM)}"].append(c)
+			 if c.delivery_start.date() == c.delivery_end.date()
+			 else contracts[f"{time_from.strftime(DATE_YMD_TIME_HM)} - {c.delivery_end.strftime(DATE_YMD_TIME_HM)}"].append(c)
+			 for c in new_contracts if _check_contracts(c, delivery_areas, products, allow_udc)]
 
 			time_from += timedelta(minutes=timeframes[contract_time])
 
