@@ -42,7 +42,10 @@ def get_orders(contract_hist_data: dict[str, pd.DataFrame]) -> dict[str, list[di
 							x["best_bid_qty"] = round(value.loc[nr, "best_bid_quantity"], 2)
 							x["best_ask"] = round(value.loc[nr, "best_ask_price"], 2)
 							x["best_ask_qty"] = round(value.loc[nr, "best_ask_quantity"], 2)
-							x["vwap"] = round(value.loc[nr, "vwap"], 2)
+							try:
+								x["vwap"] = round(value.loc[nr, "vwap"], 2)
+							except:
+								pass
 							x["as_of"] = value.loc[nr]["as_of"].tz_convert(timezone.utc) if value.loc[nr]["as_of"].tzinfo else \
 							value.loc[nr]["as_of"].tz_localize(timezone.utc)
 							bids_asks.append(x)
@@ -53,11 +56,11 @@ def get_orders(contract_hist_data: dict[str, pd.DataFrame]) -> dict[str, list[di
 					if v and k in ["bids", "asks"]:
 						for x in v:
 							x["type"] = k[:-1]
-							x["best_bid"] = round(value[nr]["best_bid"], 2)
-							x["best_bid_qty"] = round(value[nr]["best_bid_qty"], 2)
-							x["best_ask"] = round(value[nr]["best_ask"], 2)
-							x["best_ask_qty"] = round(value[nr]["best_ask_qty"], 2)
-							x["vwap"] = round(value[nr]["vwap"], 2)
+							x["best_bid"] = round(value[nr].get("best_bid", 0), 2)
+							x["best_bid_qty"] = round(value[nr].get("best_bid_qty", 0), 2)
+							x["best_ask"] = round(value[nr].get("best_ask", 0), 2)
+							x["best_ask_qty"] = round(value[nr].get("best_ask_qty", 0), 2)
+							x["vwap"] = round(value[nr].get("vwap", 0), 2)
 							x["as_of"] = value[nr]["as_of"].tz_convert(timezone.utc) if value[nr]["as_of"].tzinfo else \
 								value[nr]["as_of"].tz_localize(timezone.utc)
 							bids_asks.append(x)
@@ -230,6 +233,10 @@ def get_orderbooks(contract_hist_data: dict[str, pd.DataFrame],
 	Returns:
 		dict{key: DataFrame}: Dictionary of DataFrames
 	"""
+	# Initial check
+	if not contract_hist_data:
+		raise ValueError("Warning: Provided order data is empty")
+
 	# Setup
 	all_order_books = {}
 	host = api_client.configuration.host if isinstance(api_client, ApiClient) else None
@@ -466,6 +473,9 @@ def calc_trade_vwap(api_client: ApiClient,
 	Returns:
 		DataFrame: Trade Data with added calculated fields
 	"""
+	if not trade_data and contract_time == "all":
+		raise ValueError("Contract time can only be one of hourly, half-hourly or quarter-hourly if no trade data is given")
+
 	# Setup
 	indices = {"all": 1980, "ID3": 180, "ID1": 60}
 	contract_api = ContractApi(api_client)
