@@ -270,7 +270,10 @@ def get_historic_contract_ids(client: HistoryApiClient,
 
 		# Block product filter
 		if not contract_time == "all" or not allow_udc:
-			index = index.loc[index.undrlng_contracts.isna()]
+			if client.exchange not in SYSTEMS["NordPool"]:
+				index = index.loc[index.undrlng_contracts.isna()]
+			else:
+				index = index.loc[index.productType != "CUSTOM_BLOCK"]
 
 		[contracts[
 			f'{datetime.strftime(v.delivery_start, DATE_YMD_TIME_HM)} - {datetime.strftime(v.delivery_end, TIME_HM if v.delivery_start.date() == v.delivery_end.date() else DATE_YMD_TIME_HM)}'].append(
