@@ -7,7 +7,7 @@ from typing import Union
 
 import pandas as pd
 
-from powerbot_backtesting.utils import _cache_data, _find_cache, _historic_data_transformation
+from powerbot_backtesting.utils import _cache_data, _find_cache, _historic_data_transformation, _historic_contract_transformation
 from powerbot_backtesting.utils.constants import *
 
 
@@ -34,14 +34,7 @@ def process_historic_data(extracted_files: Union[list[str], dict[str, list[str]]
         delivery_area = filename.split("_")[0]
 
         # Contract file transformation & caching -> serves as index file
-        index = pd.json_normalize(json.load(open(contract_file)))[
-            ["deliveryAreas", "deliveryEnd", "deliveryStart", "details.contractId", "details.prod", "details.actPoint",
-             "details.expPoint", "details.undrlngContracts.contractId"]]
-        index.rename(columns={"details.contractId": 'contract_id', "deliveryAreas": 'delivery_areas',
-                              "deliveryStart": 'delivery_start', "deliveryEnd": 'delivery_end',
-                              "details.prod": '_product', "details.actPoint": 'activation_time',
-                              "details.expPoint": 'expiry_time', 'details.undrlngContracts.contractId': 'undrlng_contracts'},
-                     inplace=True)
+        index = _historic_contract_transformation(contract_file, exchange)
 
         # Group contracts after delivery period
         index['delivery_start'] = pd.to_datetime(index['delivery_start'])
@@ -102,4 +95,3 @@ def process_historic_data(extracted_files: Union[list[str], dict[str, list[str]]
 
     if not all(i for i in history_files) and not keep_zip_files:
         shutil.rmtree(history_path)
-    shutil.rmtree(history_path.joinpath(""))
