@@ -5,11 +5,12 @@ from decimal import Decimal, getcontext
 from pathlib import Path
 from time import sleep
 from typing import Union
+import json
 
 import pandas as pd
 from powerbot_client import ApiClient, TradesApi, SignalsApi, Signal, Trade, InternalTrade, OrdersApi, OwnOrder
 
-from powerbot_backtesting.utils import *
+from powerbot_backtesting.utils.constants import *
 from powerbot_backtesting.models import HistoryApiClient
 
 
@@ -220,15 +221,25 @@ def _check_contracts(contract, delivery_areas: list[str], products: list[str], a
 	Returns:
 		bool
 	"""
-	if delivery_areas and contract.delivery_areas and not any(
-			area in contract.delivery_areas for area in delivery_areas) \
-			or delivery_areas and contract.contract_details["deliveryAreas"] and not any(
-		area in contract.contract_details["deliveryAreas"] for area in delivery_areas) \
-			or delivery_areas and not contract.delivery_areas and not contract.contract_details["deliveryAreas"] \
-			or products and contract.product not in products \
-			or not products and "10YGB----------A" not in delivery_areas and contract.product == "GB_Hour_Power"\
-			or contract.type == "UDC" and not allow_udc:
-		return False
+	if contract.exchange in SYSTEMS["M7"]:
+		if delivery_areas and contract.delivery_areas and not any(
+				area in contract.delivery_areas for area in delivery_areas) \
+				or delivery_areas and contract.contract_details["deliveryAreas"] and not any(
+			area in contract.contract_details["deliveryAreas"] for area in delivery_areas) \
+				or delivery_areas and not contract.delivery_areas and not contract.contract_details["deliveryAreas"] \
+				or products and contract.product not in products \
+				or not products and "10YGB----------A" not in delivery_areas and contract.product == "GB_Hour_Power"\
+				or contract.type == "UDC" and not allow_udc:
+			return False
+
+	else:
+		if delivery_areas and contract.delivery_areas and not any(
+				area in contract.delivery_areas for area in delivery_areas) \
+				or delivery_areas and not contract.delivery_areas \
+				or products and contract.product not in products \
+				or contract.type == "UDC" and not allow_udc:
+			return False
+
 	return True
 
 
@@ -370,7 +381,7 @@ def _orderbook_data_transformation(orders: pd.DataFrame) -> pd.DataFrame:
 				if row[side] and not isinstance(row[side], float):
 					for entry in row[side]:
 						entry["type"] = side[:-1]
-						entry["as_of"] = row["as_of"].tz_localize(timezone.utc)
+						entry["as_of"] = row["as_of"].tz_convert(timezone.utc) if row["as_of"].tzinfo else row["as_of"].tz_localize(timezone.utc)
 						entry["delta"] = row["delta"]
 						bids_asks.append(entry)
 
@@ -410,6 +421,24 @@ def _delta_filter(orderbook: pd.DataFrame) -> pd.DataFrame:
 	return orderbook.drop(columns=["delta"])
 
 
+def _historic_contract_transformation(path_to_file: str, exchange: str) -> pd.DataFrame:
+	if exchange in SYSTEMS["M7"]:
+		index = pd.json_normalize(json.load(open(path_to_file)))[
+			["deliveryAreas", "deliveryEnd", "deliveryStart", "details.contractId", "details.prod", "details.actPoint",
+			 "details.expPoint", "details.undrlngContracts.contractId"]]
+	else:
+		index = pd.DataFrame(json.load(open(path_to_file)))
+		index.rename(columns={"_id": "contract_id", "product": "_product"}, inplace=True)
+
+	index.rename(columns={"details.contractId": 'contract_id', "deliveryAreas": 'delivery_areas',
+	                      "deliveryStart": 'delivery_start', "deliveryEnd": 'delivery_end',
+	                      "details.prod": '_product', "details.actPoint": 'activation_time',
+	                      "details.expPoint": 'expiry_time', 'details.undrlngContracts.contractId': 'undrlng_contracts'},
+	             inplace=True)
+
+	return index
+
+
 def _historic_data_transformation(files: list, exchange: str, filetype: str) -> pd.DataFrame:
 	"""
 	Function transforms historic data into correct format to be used with other data processing functions.
@@ -430,7 +459,7 @@ def _historic_data_transformation(files: list, exchange: str, filetype: str) ->
 		else:
 			df = df.append(pd.read_json(file), ignore_index=True)
 
-	if exchange != "nordpool":
+	if exchange in SYSTEMS["M7"]:
 		if filetype == "trades":
 			df.drop(columns=["revisionNo"], inplace=True)
 			df.rename(columns={"_id": "trade_id", "contractId": 'contract_id', "tradeExecTime": 'exec_time',
@@ -514,6 +543,7 @@ def _historic_data_transformation(files: list, exchange: str, filetype: str) ->
 						 "turnover": "total_quantity"},
 				inplace=True)
 
+			df["delta"] = [False if "snapshot" in i else True for i in df.details]
 			df.revision_no = [i for i in range(0, len(df))]
 			df.delivery_area = [NORDPOOL_EIC_CODES[i] for i in df.delivery_area.tolist()]
 			asks = [i["asks"] if "asks" in i else None for i in df.details.tolist()]
